==> jc-1.4.0.tar.gz: java/lang/Character__24Subset.h <==
// public class java.lang.Character$Subset

// class file dependencies
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Character__24Subset_H_
#define _JC_java_lang_Character__24Subset_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Character__24Subset$sub_refs	_jc_java_lang_Character__24Subset$sub_refs;
typedef struct _jc_java_lang_Character__24Subset$sub_nonrefs	_jc_java_lang_Character__24Subset$sub_nonrefs;
typedef struct _jc_java_lang_Character__24Subset$refs	_jc_java_lang_Character__24Subset$refs;
typedef struct _jc_java_lang_Character__24Subset$nonrefs	_jc_java_lang_Character__24Subset$nonrefs;
typedef struct _jc_java_lang_Character__24Subset$object	_jc_java_lang_Character__24Subset$object;

typedef const struct _jc_java_lang_Character__24Subset$vmethods	_jc_java_lang_Character__24Subset$vmethods;
typedef const struct _jc_java_lang_Character__24Subset$vtable	_jc_java_lang_Character__24Subset$vtable;
typedef const struct _jc_java_lang_Character__24Subset$vtype	_jc_java_lang_Character__24Subset$vtype;

// Constructors
extern void _jc_java_lang_Character__24Subset$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_Character__24Subset$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_Character__24Subset$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_lang_Character__24Subset$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_Character__24Subset$object *);
extern struct _jc_java_lang_String$object *_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_lang_Character__24Subset$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_Character__24Subset$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_Character__24Subset$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_lang_Character__24Subset$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_lang_Character__24Subset$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_Character__24Subset$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_Character__24Subset$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_lang_Character__24Subset$object *);
};

// Vtable
struct _jc_java_lang_Character__24Subset$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Character__24Subset$vmethods	java_lang_Character__24Subset;
};

// Vtype
struct _jc_java_lang_Character__24Subset$vtype {
	_jc_type			type;
	_jc_java_lang_Character__24Subset$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Character__24Subset$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_lang_Character__24Subset$refs {
    _jc_java_lang_Character__24Subset$sub_refs	java_lang_Character__24Subset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Character__24Subset$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Character__24Subset$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Character__24Subset$sub_nonrefs	java_lang_Character__24Subset;
};

// Object instance structure
struct _jc_java_lang_Character__24Subset$object {
	_jc_java_lang_Character__24Subset$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Character__24Subset$vtype	*vtype;
	_jc_java_lang_Character__24Subset$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Character__24Subset$vtype _jc_java_lang_Character__24Subset$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Character__24Subset, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Character__24Subset$class_object;

#endif	/* _JC_java_lang_Character__24Subset_H_ */

==> jc-1.4.6.tar.gz: java/lang/Character__24Subset.h <==
// public class java.lang.Character$Subset

// class file dependencies
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Character__24Subset_H_
#define _JC_java_lang_Character__24Subset_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Character__24Subset$sub_refs	_jc_java_lang_Character__24Subset$sub_refs;
typedef struct _jc_java_lang_Character__24Subset$sub_nonrefs	_jc_java_lang_Character__24Subset$sub_nonrefs;
typedef struct _jc_java_lang_Character__24Subset$refs	_jc_java_lang_Character__24Subset$refs;
typedef struct _jc_java_lang_Character__24Subset$nonrefs	_jc_java_lang_Character__24Subset$nonrefs;
typedef struct _jc_java_lang_Character__24Subset$object	_jc_java_lang_Character__24Subset$object;

typedef const struct _jc_java_lang_Character__24Subset$vmethods	_jc_java_lang_Character__24Subset$vmethods;
typedef const struct _jc_java_lang_Character__24Subset$vtable	_jc_java_lang_Character__24Subset$vtable;
typedef const struct _jc_java_lang_Character__24Subset$vtype	_jc_java_lang_Character__24Subset$vtype;

// Constructors
extern void _jc_java_lang_Character__24Subset$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_Character__24Subset$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_Character__24Subset$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_Character__24Subset$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_Character__24Subset$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_lang_Character__24Subset$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_Character__24Subset$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_Character__24Subset$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_lang_Character__24Subset$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_lang_Character__24Subset$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_Character__24Subset$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_Character__24Subset$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_lang_Character__24Subset$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_Character__24Subset$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Character__24Subset$vmethods	java_lang_Character__24Subset;
};

// Vtype
struct _jc_java_lang_Character__24Subset$vtype {
	_jc_type			type;
	_jc_java_lang_Character__24Subset$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Character__24Subset$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_lang_Character__24Subset$refs {
    _jc_java_lang_Character__24Subset$sub_refs	java_lang_Character__24Subset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Character__24Subset$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Character__24Subset$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Character__24Subset$sub_nonrefs	java_lang_Character__24Subset;
};

// Object instance structure
struct _jc_java_lang_Character__24Subset$object {
	_jc_java_lang_Character__24Subset$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Character__24Subset$vtype	*vtype;
	_jc_java_lang_Character__24Subset$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Character__24Subset$vtype _jc_java_lang_Character__24Subset$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Character__24Subset, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Character__24Subset$class_object;

#endif	/* _JC_java_lang_Character__24Subset_H_ */
